#!/bin/bash
#Description: DevKit install tool
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2025. All rights reserved.

current_dir=$(readlink -f "$(dirname "$0")")
# 定义文件名
url_file="${current_dir}/url.ini"
# 并行下载的进程数
num_processes=5

if [ ! -e ${url_file} ]; then
	echo 'The url.ini file is not exists'
    exit 1
fi

# 读取文件中的每一行
while IFS= read -r url; do
  # 将 URL 添加到数组中
  urls+=("${url}")
done < "${url_file}"

# 定义下载函数
download_file() {
    local url=$1
    local output_dir=$2

    # 提取文件名（假设URL以文件名结尾）
    local filename=$(basename "$url")

    echo "Start downloading: $filename"
    wget -q --show-progress -P "$output_dir" "$url"
    if [ $? -eq 0 ]; then
        echo "Downloaded: $filename"
    else
        echo "Download failed: $filename"
    fi
}

# 创建一个目录用于存放下载的文件
mkdir -p downloads

# 获取CPU核心数
cpu_cores=$(cat /proc/cpuinfo | grep "processor" | wc -l)

# 启动一个子shell来管理后台进程
(
    for url in "${urls[@]}"; do
        while [ $(jobs -r | wc -l) -ge "$cpu_cores" ]; do
            sleep 1  # 等待一个进程结束
        done
        download_file "$url" "downloads" &
    done
    wait  # 等待所有后台作业完成
)

echo "All files have been downloaded."
