#!/bin/bash
#Description: const params
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2020. All rights reserved.
#History: 2020-05-11 created

# 获取系统磁盘空间，检查磁盘空间是否满足安装
function disk_space_check()
{
    local install_path=$1
    local disk_space_need=$2
    local install_path_parent=$(dirname "${install_path}")
    # 获取磁盘的百分之十的大小，与disk_space_need比较
    local total_size=$(df "${install_path_parent}" | awk 'NR==2' | awk '{print $2}')
    local percent_size=$(expr ${total_size} / 10)
    if [[ ${percent_size} -gt ${TOOL_USE_SPACE} ]]; then
        disk_space_need=`expr ${TOOL_USE_SPACE} + ${disk_space_need}`
    else
        disk_space_need=`expr ${percent_size} + ${disk_space_need}`
    fi

    local available_space=$(df "$install_path_parent" | awk 'NR==2' | awk '{print $4}')
    if [[ ${available_space} -lt ${disk_space_need} ]]; then
        print_disk_space_need=`expr ${disk_space_need} / 1000 / 1000`
        echo_and_log "Insufficient drive space. At least ${print_disk_space_need} GB free space is required. Release drive space and try again." "${ERROR}"
        return "${ERROR}"
    fi
    return "${SUCCESS}"
}

function get_size {
    local target_path=$1
    local size=0
    if [[ -z "${target_path}" ]]; then
      echo "${size}"
      return "${ERROR}"
    fi
    if [[ -f "${target_path}" || -d "${target_path}" ]]; then
      size=$(du "${target_path}" --max-depth=0 | awk 'NR==1' | awk '{print $1}')
      echo "${size}"
      return "${SUCCESS}"
    else
      echo "${size}"
      return "${ERROR}"
    fi
}

function agent_disk_space_check {
    local install_path=$1
    local disk_space_need=$2
    local install_path_parent=$(dirname "${install_path}")
    # 获取磁盘的百分之十的大小，与disk_space_need比较
    local total_size=$(df "${install_path_parent}" | awk 'NR==2' | awk '{print $2}')
    local percent_size=$(expr ${total_size} / 10)
    if [[ ${percent_size} -gt ${TOOL_USE_SPACE} ]]; then
        disk_space_need=`expr ${TOOL_USE_SPACE} + ${disk_space_need}`
    else
        disk_space_need=`expr ${percent_size} + ${disk_space_need}`
    fi
    # 获取安装包位置
    local package_store_path="/opt"
    local install_ini="${install_path}/config/install.ini"
    if [[ -f "${install_ini}" ]]; then
        node_user=$(grep -w NODE_INSTALLER "${install_ini}" | awk -F= '{if($2 !="") print $2}')
        if [[ "${node_user}" != "root" ]]; then
            package_store_path="/home/${node_user}"
        fi
    fi
    local agent_package_path="${package_store_path}/agent_install_packages.tar.gz"
    local agent_package_dir_path="${package_store_path}/agent_install_packages"
    # 获取已安装文件以及安装包的大小
    local agent_package_size=$(get_size "${agent_package_path}")
    local agent_package_dir_size=$(get_size "${agent_package_dir_path}")
    local devkit_installed_size=$(get_size "${install_path}")

    # 比较可用空间与所需空间
    local available_space=$(df "$install_path_parent" | awk 'NR==2' | awk '{print $4}')
    if [[ ${available_space} -lt ${disk_space_need} ]]; then
        print_disk_space_need=${disk_space_need}
        # 安装失败后会清理残留，因此提示用户的所需容量需包含已scp过来的安装包，以及已安装的agent文件
        local package_store_mnt_point=$(df "${package_store_path}" | awk 'NR==2' | awk '{print $6}')
        local devkit_install_mnt_point=$(df "${install_path}" | awk 'NR==2' | awk '{print $6}')
        if [[ "${package_store_mnt_point}" == "${devkit_install_mnt_point}" ]]; then
            print_disk_space_need=`expr ${agent_package_size} + ${agent_package_dir_size} + ${devkit_installed_size} + ${disk_space_need}`
        else
            print_disk_space_need=`expr ${devkit_installed_size} + ${disk_space_need}`
        fi
        # 提示所需空间向上取整
        local ceil_block=`expr 1024 \* 1024 - 1`
        print_disk_space_need=`expr ${print_disk_space_need} + ${ceil_block}`
        print_disk_space_need=`expr ${print_disk_space_need} / 1024 / 1024`
        echo_and_log "Insufficient drive space. " "${ERROR}"
        echo_and_log "At least ${print_disk_space_need} GB free space is required including the agent framework that has been installed. " "${ERROR}"
        echo_and_log "Release drive space and try again." "${ERROR}"
        return "${ERROR}"
    fi
    return "${SUCCESS}"
}

# 终端及日志打印:echo_and_log [info] [status] [log]
function echo_and_log()
{
    local info=$1
    local status=$2
    local log=""
    local type="32"
    if [[ $# == 3 ]]; then
        log=$3 # 选填
        if [[ ! -f "${log}" ]]; then
            echo -e "\e[1;31m echo_and_log:${log} is not exist \e[0m"
            exit "${ERROR}"
        fi
    fi

    case "${status}" in
        0)
            type="32";;
        1)
            type="31";;
        2)
            type="33";;
        3)
            type="37";; # 白色
        *)
            echo -e "\e[1;31m status: 0/1/2, input is ${status} \e[0m";;
    esac
    if [[ -z "${log}" ]]; then
        echo -e "\e[1;${type}m  ${info} \e[0m"
    else
        if [[ ! -f "${log}" ]]; then
            echo -e "\e[1;31m echo_and_log:${log} is not exist \e[0m"
            exit "${ERROR}"
        fi
        echo -e "\e[1;${type}m  ${info} \e[0m" | tee -a "${log}"
    fi
}

function delete_sudo_tools()
{
    local LOG=$1
    echo_and_log "Delete sudo tools" "${DOING}" "${LOG}"
    if [[ -f "${SUDO_FILE}" ]]; then
        rm -f "${SUDO_FILE}"
    fi
    echo_and_log "Delete sudo tools success" "${SUCCESS}" "${LOG}"
}

function x2openEuler_deploy()
{
    local LOG=$1
    local mode=$2
    local x2openEuler_install_deploy="${install_path}/devkitplugins/porting/cmd/x2openEuler_install/deploy-x2openEuler"
    local x2openEuler_rpm_path="${install_path}/devkitplugins/porting/cmd/x2openEuler_install/rpm"
    local x2openEuler_migrate_tool="/usr/bin/x2openEuler-migrate"
    if [[ -d "${x2openEuler_rpm_path}" ]]; then
        local x2openEuler_install_rpm="$(find "${x2openEuler_rpm_path}" -type f -name "*.aarch64.rpm" -print -quit)"
    fi
    if [[ -f "${x2openEuler_migrate_tool}" ]]; then
        if [[ -f "${x2openEuler_install_deploy}" && -n "${x2openEuler_install_rpm}" ]]; then
            bash "${x2openEuler_install_deploy}" "-p" "${x2openEuler_install_rpm}" "${mode}"
            if [[ $? -ne "0" ]]; then
                echo_and_log "Failed to ${mode} x2openEuler" "${ERROR}" "${LOG}"
            else
                echo_and_log "Successfully ${mode}ed x2openEuler" "${SUCCESS}" "${LOG}"
            fi
        else
            echo_and_log "Failed to find x2openEuler deployment file" "${ERROR}" "${LOG}"
        fi
    fi
}